# ISA

Projeto ISA (**I**s´nt **S**ql **A**nymore) é um biblioteca python que provê a inteligencia para resolução dos nomes e parsers expandindo as funcionalidades padrão do *Spark SQL*

## Install

```sh
pip install dora-isa
```